@@ -7,10 +7,10 @@
 #' @param wrt integer; Selects the regressor to differentiate with respect to.
 #' @param order integer; \link{NNS.reg} \code{"order"}, defaults to NULL.
 #' @param stn numeric [0,1]; Signal to noise parameter, sets the threshold of \link{NNS.dep} which reduces \code{"order"} when \code{(order=NULL)}.  Defaults to 0.99 to ensure high dependence for higher \code{"order"} and endpoint determination.
-#' @param eval.points numeric or options: ("mean", median", "last"); Regressor points to be evaluated.  \code{eval.points="median"} (default) to find partial derivatives at the median of every variable.  Set to \code{eval.points="last"} to find partial derivatives at the last value of every variable.  Set to \code{eval.points="mean"} to find partial derivatives at the mean value of every variable.
+#' @param eval.points numeric or options: ("mean", median", "last"); Regressor points to be evaluated.  \code{(eval.points="median")} (default) to find partial derivatives at the median of every variable.  Set to \code{(eval.points="last")} to find partial derivatives at the last value of every variable.  Set to \code{(eval.points="mean")} to find partial derivatives at the mean value of every variable. Set to \code{(eval.points="all")} to find partial derivatives at every observation.
 #' @param h numeric [0,...]; Percentage step used for finite step method.  Defaults to \code{h=.05} representing a 5 percent step from the value of the regressor.
 #' @param n.best integer; Sets the number of closest regression points to use in estimating finite difference points in \link{NNS.reg}.  \code{NULL} (default) Uses \code{ceiling(sqrt(ncol(x)))}.
-#' @param mixed logical; \code{FALSE} (default) If mixed derivative is to be evaluated, set \code{(mixed=TRUE)}.
+#' @param mixed logical; \code{FALSE} (default) If mixed derivative is to be evaluated, set \code{(mixed=TRUE)}.  Only for single valued \code{eval.points}.
 #' @param plot logical; \code{FALSE} (default) Set to \code{(plot=TRUE)} to view plot.
 #' @param noise.reduction the method of determing regression points options: ("mean","median","mode","off"); In low signal to noise situations, \code{(noise.reduction="median")} uses medians instead of means for partitions, while \code{(noise.reduction="mode")} uses modes instead of means for partitions.  \code{(noise.reduction="off")}  allows for maximum possible fit in \link{NNS.reg}. Default setting is \code{(noise.reduction="mean")}.
 #' @return Returns:
@@ -19,6 +19,7 @@
 #' \item{\code{dy.d_(...)$"Second Derivative"}} the 2nd derivative
 #' \item{\code{dy.d_(...)$"Mixed Derivative"}} the mixed derivative (for two independent variables only).
 #' }
+#' Retuns a vector of partial derivatives when \code{(eval.points="all")}.
 #' @note For known function testing and analysis, regressors should be transformed via \link{expand.grid} to fill the dimensions with \code{(order="max")}.  Example provided below.
 #' @keywords multivaiate partial derivative
 #' @author Fred Viole, OVVO Financial Systems
@@ -39,28 +40,33 @@
 
 dy.d_<- function(x,y,wrt,eval.points="median",order=NULL,stn=0.99,h=.05,n.best=NULL,mixed=FALSE,plot=FALSE,noise.reduction='mean'){
   if(is.null(n.best)){n.best=ceiling(sqrt(ncol(x)))}else{n.best=n.best}
-  if(eval.points[1]=="median"){
+
+  if(is.character(eval.points)){
+  if(eval.points=="median"){
     eval.points=numeric()
     eval.points=apply(x,2,median)}
-  if(eval.points[1]=="last"){
+  if(eval.points=="last"){
     eval.points=numeric()
     eval.points=as.numeric(x[length(x[,1]),])}
-  if(eval.points[1]=="mean"){
+  if(eval.points=="mean"){
     eval.points=numeric()
     eval.points=apply(x,2,mean)}
+  if(eval.points=="all"){
+    eval.points=x}
+}
+
 
   original.eval.points.min=eval.points
   original.eval.points.max=eval.points
 
+  if(is.null(dim(eval.points))){
   original.eval.points.min[wrt] = (1-h)*original.eval.points.min[wrt]
   original.eval.points.max[wrt] = (1+h)*original.eval.points.max[wrt]
 
   deriv.points = matrix(c(original.eval.points.min,eval.points,original.eval.points.max),ncol=length(eval.points),byrow = TRUE)
 
-
   estimates = NNS.reg(x,y,order=order,point.est = deriv.points,n.best=n.best,stn = stn,plot=plot,noise.reduction=noise.reduction)$Point.est
 
-
   lower=estimates[1]
   two.f.x = 2*estimates[2]
   upper=estimates[3]
@@ -70,10 +76,33 @@ dy.d_<- function(x,y,wrt,eval.points="median",order=NULL,stn=0.99,h=.05,n.best=N
   distance.1 = sqrt(sum(sweep(t(c(original.eval.points.max)),2,t(c(eval.points)))^2))
   distance.2 = sqrt(sum(sweep(t(c(original.eval.points.min)),2,t(c(eval.points)))^2))
   run=distance.1+distance.2
+  } else {
+
+    original.eval.points=eval.points
+    original.eval.points.min[,wrt] = (1-h)*original.eval.points.min[,wrt]
+    original.eval.points.max[,wrt] = (1+h)*original.eval.points.max[,wrt]
+
+    estimates=NNS.reg(x,y,order=order,point.est = original.eval.points,n.best=n.best,stn = stn,plot=plot,noise.reduction=noise.reduction)$Point.est
+    estimates.min = NNS.reg(x,y,order=order,point.est =original.eval.points.min,n.best=n.best,stn = stn,plot=plot,noise.reduction=noise.reduction)$Point.est
+    estimates.max = NNS.reg(x,y,order=order,point.est = original.eval.points.max,n.best=n.best,stn = stn,plot=plot,noise.reduction=noise.reduction)$Point.est
+
+    lower=estimates.min
+    two.f.x = 2*estimates
+    upper=estimates.max
+
+    rise = upper-lower
+
+    distance.1 = rowSums(abs(original.eval.points.max-eval.points))
+    distance.2 = rowSums(abs(original.eval.points.min-eval.points))
+    run=distance.1+distance.2
+  }
+
 
 
   if(mixed==TRUE){
+  if(is.null(dim(eval.points))){
   if(length(eval.points)!=2){return("Mixed Derivatives are only for 2 IV")}
+    }else{ if(ncol(eval.points)!=2){return("Mixed Derivatives are only for 2 IV")}}
   mixed.deriv.points = matrix(c((1+h)*eval.points,
                                 (1-h)*eval.points[1],(1+h)*eval.points[2],
                                 (1+h)*eval.points[1],(1-h)*eval.points[2],
